@@ -36,8 +36,7 @@
 
 #include <kdebug.h>
 
-
-class KateWordCompletionModel : public KTextEditor::CodeCompletionModel2, public KTextEditor::CodeCompletionModelControllerInterface4
+class KATEPART_TESTS_EXPORT KateWordCompletionModel : public KTextEditor::CodeCompletionModel2, public KTextEditor::CodeCompletionModelControllerInterface4
 {
   Q_OBJECT
   Q_INTERFACES(KTextEditor::CodeCompletionModelControllerInterface4)
@@ -74,7 +73,7 @@ class KateWordCompletionModel : public KTextEditor::CodeCompletionModel2, public
 
     virtual bool shouldHideItemsWithEqualNames() const;
 
-    const QStringList allMatches( KTextEditor::View *view, const KTextEditor::Range &range ) const;
+    QStringList allMatches( KTextEditor::View *view, const KTextEditor::Range &range ) const;
 
     virtual void executeCompletionItem2(KTextEditor::Document* document, const KTextEditor::Range& word, const QModelIndex& index) const;
 
@@ -103,8 +102,8 @@ class KateWordCompletionView : public QObject
   private:
     void complete( bool fw=true );
 
-    const QString word() const;
-    const KTextEditor::Range range() const;
+    QString word() const;
+    KTextEditor::Range range() const;
 
     QString findLongestUnique( const QStringList &matches, int lead ) const;
 
